@@ -1,6 +1,6 @@
 import json
 
-from moto.core import BackendDict, BaseBackend
+from moto.core.base_backend import BackendDict, BaseBackend
 
 
 class Ec2InstanceConnectBackend(BaseBackend):
